==> nsafirstlibrary-1.0.0.tgz: package/resources/dispatches.js <==
'use strict';

// Include global module
var globals = require('../global')

//Declare token
var token;

//Declare url
var url;

module.exports = {

    //List Dispatches method request
    getDispatches: function (path, host, currentObject, success) {

        // Assign Complete url
        url = host + path;

        //Define Bearer authorization
        token = 'Bearer ' + currentObject.state.token;

        //Set request
        globals.https.get(url)
            .set('Content-Type', 'application/json')
            .set('Authorization', token)
            .set('latitude', currentObject.state.latitude)
            .set('longitude', currentObject.state.longitude)
            .end(function (error, response) {
                if (response)
                    success(response.body, JSON.parse(response.statusCode), currentObject);
                else
                    success(globals.errBody, globals.errStatusCode, currentObject);
            })
    },

    //List Dispatches with Hash key method request
    getDispatchesWithHash: function (path, host, currentObject, success) {

        // Assign Complete url
        url = host + path;

        //Define Bearer authorization
        token = 'Bearer ' + currentObject.state.token;

        //Set request
        globals.https.post(url)
            .set('Content-Type', 'application/json')
            .set('Authorization', token)
            .set('latitude', currentObject.state.latitude)
            .set('longitude', currentObject.state.longitude)
            .send(JSON.stringify(currentObject.state.requestData))
            .end(function (error, response) {
                if (response)
                    success(response.body, JSON.parse(response.statusCode), currentObject);
                else
                    success(globals.errBody, globals.errStatusCode, currentObject);
            })
    },

    //List Dispatches by Dispatch Number method request
    getDispatchesByDispatchNumber: function (path, host, currentObject, success) {

        // Assign Complete url
        url = host + path;

        //Define Bearer authorization
        token = 'Bearer ' + currentObject.state.token;

        //Set request
        globals.https.get(url)
            .set('Content-Type', 'application/json')
            .set('Authorization', token)
            .set('latitude', currentObject.state.latitude)
            .set('longitude', currentObject.state.longitude)
            .end(function (error, response) {
                if (response)
                    success(response.body, JSON.parse(response.statusCode), currentObject);
                else
                    success(globals.errBody, globals.errStatusCode, currentObject);
            })
    },

    //Update Dispatch by Dispatch Number method request
    updateDispatchesByDispatchNumber: function (path, host, currentObject, success) {

        // Assign Complete url
        url = host + path;

        //Define Bearer authorization
        token = 'Bearer ' + currentObject.state.token;

        //Set request
        globals.https.put(url)
            .set('Content-Type', 'application/json')
            .set('Authorization', token)
            .set('latitude', currentObject.state.latitude)
            .set('longitude', currentObject.state.longitude)
            .send(JSON.stringify(currentObject.state.requestData))
            .end(function (error, response) {
                if (response)
                    success(response.body, JSON.parse(response.statusCode), currentObject);
                else
                    success(globals.errBody, globals.errStatusCode, currentObject);
            })
    },

    //Update Dispatch Schedule by date method request
    updateDispatchesSchedules: function (path, host, currentObject, success) {

        // Assign Complete url
        url = host + path;

        //Define Bearer authorization
        token = 'Bearer ' + currentObject.state.token;

        //Set request
        globals.https.post(url)
            .set('Content-Type', 'application/json')
            .set('Authorization', token)
            .set('latitude', currentObject.state.latitude)
            .set('longitude', currentObject.state.longitude)
            .send(JSON.stringify(currentObject.state.requestData))
            .end(function (error, response) {
                if (response)
                    success(response.body, JSON.parse(response.statusCode), currentObject);
                else
                    success(globals.errBody, globals.errStatusCode, currentObject);
            })
    },

    //Update Dispatch Completions method request
    updateDispatchesCompletions: function (path, host, currentObject, success) {

        // Assign Complete url
        url = host + path;

        //Define Bearer authorization
        token = 'Bearer ' + currentObject.state.token;

        //Set request
        globals.https.post(url)
            .set('Content-Type', 'application/json')
            .set('Authorization', token)
            .set('latitude', currentObject.state.latitude)
            .set('longitude', currentObject.state.longitude)
            .send(JSON.stringify(currentObject.state.requestData))
            .end(function (error, response) {
                if (response)
                    success(response.body, JSON.parse(response.statusCode), currentObject);
                else
                    success(globals.errBody, globals.errStatusCode, currentObject);
            })
    },

    //List Dispatches Attachment by Dispatch Number method request
    getDispatchesAttachments: function (path, host, currentObject, success) {

        // Assign Complete url
        url = host + path;

        //Define Bearer authorization
        token = 'Bearer ' + currentObject.state.token;

        //Set request
        globals.https.get(url)
            .set('Content-Type', 'application/json')
            .set('Authorization', token)
            .set('latitude', currentObject.state.latitude)
            .set('longitude', currentObject.state.longitude)
            .end(function (error, response) {
                if (response)
                    success(response.body, JSON.parse(response.statusCode), currentObject);
                else
                    success(globals.errBody, globals.errStatusCode, currentObject);
            })
    },

    //Add Dispatches Attachment by Dispatch Number method request
    addDispatchesAttachments: function (path, host, currentObject, success) {

        // Assign Complete url
        url = host + path;

        //Define Bearer authorization
        token = 'Bearer ' + currentObject.state.token;

        //Set request
        globals.https.post(url)
            .set('Content-Type', 'application/json')
            .set('Authorization', token)
            .set('latitude', currentObject.state.latitude)
            .set('longitude', currentObject.state.longitude)
            .send(JSON.stringify(currentObject.state.requestData))
            .end(function (error, response) {
                if (response)
                    success(response.body, JSON.parse(response.statusCode), currentObject);
                else
                    success(globals.errBody, globals.errStatusCode, currentObject);
            })
    }

}

==> nsafirstlibrary-2.0.0.tgz: package/resources/dispatches.js <==
'use strict';

// Include global module
var globals = require('../global')

//Declare url
var url;

module.exports = {

    //List Dispatches method request
    getDispatches: function (path, host, token, currentObject, success) {

        // Assign Complete url
        url = host + path;

        //Define Bearer authorization
        token = 'Bearer ' + token;

        //Set request
        globals.https.get(url)
            .set('Content-Type', 'application/json')
            .set('Authorization', token)
            .set('latitude', currentObject.state.latitude)
            .set('longitude', currentObject.state.longitude)
            .end(function (error, response) {
                if (response)
                    success(response.body, JSON.parse(response.statusCode), currentObject);
                else
                    success(globals.errBody, globals.errStatusCode, currentObject);
            })
    },

    //List Dispatches with Hash key method request
    getDispatchesWithHash: function (path, host, token, currentObject, success) {

        // Assign Complete url
        url = host + path;

        //Define Bearer authorization
        token = 'Bearer ' + token;

        //Set request
        globals.https.post(url)
            .set('Content-Type', 'application/json')
            .set('Authorization', token)
            .set('latitude', currentObject.state.latitude)
            .set('longitude', currentObject.state.longitude)
            .send(JSON.stringify(currentObject.state.requestData))
            .end(function (error, response) {
                if (response)
                    success(response.body, JSON.parse(response.statusCode), currentObject);
                else
                    success(globals.errBody, globals.errStatusCode, currentObject);
            })
    },

    //List Dispatches by Dispatch Number method request
    getDispatchesByDispatchNumber: function (path, host, token, currentObject, success) {

        // Assign Complete url
        url = host + path;

        //Define Bearer authorization
        token = 'Bearer ' + token;

        //Set request
        globals.https.get(url)
            .set('Content-Type', 'application/json')
            .set('Authorization', token)
            .set('latitude', currentObject.state.latitude)
            .set('longitude', currentObject.state.longitude)
            .end(function (error, response) {
                if (response)
                    success(response.body, JSON.parse(response.statusCode), currentObject);
                else
                    success(globals.errBody, globals.errStatusCode, currentObject);
            })
    },

    //Update Dispatch by Dispatch Number method request
    updateDispatchesByDispatchNumber: function (path, host, token, currentObject, success) {

        // Assign Complete url
        url = host + path;

        //Define Bearer authorization
        token = 'Bearer ' + token;

        //Set request
        globals.https.put(url)
            .set('Content-Type', 'application/json')
            .set('Authorization', token)
            .set('latitude', currentObject.state.latitude)
            .set('longitude', currentObject.state.longitude)
            .send(JSON.stringify(currentObject.state.requestData))
            .end(function (error, response) {
                if (response)
                    success(response.body, JSON.parse(response.statusCode), currentObject);
                else
                    success(globals.errBody, globals.errStatusCode, currentObject);
            })
    },

    //Update Dispatch Schedule by date method request
    updateDispatchesSchedules: function (path, host, token, currentObject, success) {

        // Assign Complete url
        url = host + path;

        //Define Bearer authorization
        token = 'Bearer ' + token;

        //Set request
        globals.https.post(url)
            .set('Content-Type', 'application/json')
            .set('Authorization', token)
            .set('latitude', currentObject.state.latitude)
            .set('longitude', currentObject.state.longitude)
            .send(JSON.stringify(currentObject.state.requestData))
            .end(function (error, response) {
                if (response)
                    success(response.body, JSON.parse(response.statusCode), currentObject);
                else
                    success(globals.errBody, globals.errStatusCode, currentObject);
            })
    },

    //Update Dispatch Completions method request
    updateDispatchesCompletions: function (path, host, token, currentObject, success) {

        // Assign Complete url
        url = host + path;

        //Define Bearer authorization
        token = 'Bearer ' + token;

        //Set request
        globals.https.post(url)
            .set('Content-Type', 'application/json')
            .set('Authorization', token)
            .set('latitude', currentObject.state.latitude)
            .set('longitude', currentObject.state.longitude)
            .send(JSON.stringify(currentObject.state.requestData))
            .end(function (error, response) {
                if (response)
                    success(response.body, JSON.parse(response.statusCode), currentObject);
                else
                    success(globals.errBody, globals.errStatusCode, currentObject);
            })
    },

    //List Dispatches Attachment by Dispatch Number method request
    getDispatchesAttachments: function (path, host, token, currentObject, success) {

        // Assign Complete url
        url = host + path;

        //Define Bearer authorization
        token = 'Bearer ' + token;

        //Set request
        globals.https.get(url)
            .set('Content-Type', 'application/json')
            .set('Authorization', token)
            .set('latitude', currentObject.state.latitude)
            .set('longitude', currentObject.state.longitude)
            .end(function (error, response) {
                if (response)
                    success(response.body, JSON.parse(response.statusCode), currentObject);
                else
                    success(globals.errBody, globals.errStatusCode, currentObject);
            })
    },

    //Add Dispatches Attachment by Dispatch Number method request
    addDispatchesAttachments: function (path, host, token, currentObject, success) {

        // Assign Complete url
        url = host + path;

        //Define Bearer authorization
        token = 'Bearer ' + token;

        //Set request
        globals.https.post(url)
            .set('Content-Type', 'application/json')
            .set('Authorization', token)
            .set('latitude', currentObject.state.latitude)
            .set('longitude', currentObject.state.longitude)
            .send(JSON.stringify(currentObject.state.requestData))
            .end(function (error, response) {
                if (response)
                    success(response.body, JSON.parse(response.statusCode), currentObject);
                else
                    success(globals.errBody, globals.errStatusCode, currentObject);
            })
    }

}
